@@ -1,12 +1,9 @@
-from __future__ import print_function
 import time
 import tempfile
 import shutil
 import unittest
 import email.utils
 from contextlib import contextmanager
-import pytest
-import sys
 
 from scrapy.http import Response, HtmlResponse, Request
 from scrapy.spiders import Spider
@@ -85,8 +82,8 @@ class _BaseTest(unittest.TestCase):
 
     def assertEqualRequestButWithCacheValidators(self, request1, request2):
         self.assertEqual(request1.url, request2.url)
-        assert not b'If-None-Match' in request1.headers
-        assert not b'If-Modified-Since' in request1.headers
+        assert b'If-None-Match' not in request1.headers
+        assert b'If-Modified-Since' not in request1.headers
         assert any(h in request2.headers for h in (b'If-None-Match', b'If-Modified-Since'))
         self.assertEqual(request1.body, request2.body)
 
@@ -137,7 +134,7 @@ class DbmStorageWithCustomDbmModuleTest(DbmStorageTest):
 
     def _get_settings(self, **new_settings):
         new_settings.setdefault('HTTPCACHE_DBM_MODULE', self.dbm_module)
-        return super(DbmStorageWithCustomDbmModuleTest, self)._get_settings(**new_settings)
+        return super()._get_settings(**new_settings)
 
     def test_custom_dbm_module_loaded(self):
         # make sure our dbm module has been loaded
@@ -149,20 +146,12 @@ class FilesystemStorageTest(DefaultStorageTest):
 
     storage_class = 'scrapy.extensions.httpcache.FilesystemCacheStorage'
 
+
 class FilesystemStorageGzipTest(FilesystemStorageTest):
 
     def _get_settings(self, **new_settings):
         new_settings.setdefault('HTTPCACHE_GZIP', True)
-        return super(FilesystemStorageTest, self)._get_settings(**new_settings)
-
-
-class LeveldbStorageTest(DefaultStorageTest):
-
-    try:
-        pytest.importorskip('leveldb')
-    except SystemError:
-        pytestmark = pytest.mark.skip("Test module skipped - 'SystemError: bad call flags' occurs when >= Python 3.8")
-    storage_class = 'scrapy.extensions.httpcache.LeveldbCacheStorage'
+        return super()._get_settings(**new_settings)
 
 
 class DummyPolicyTest(_BaseTest):
@@ -335,7 +324,7 @@ class RFC2616PolicyTest(DefaultStorageTest):
         ]
         with self._middleware() as mw:
             for idx, (shouldcache, status, headers) in enumerate(responses):
-                req0 = Request('http://example-%d.com' % idx)
+                req0 = Request(f'http://example-{idx}.com')
                 res0 = Response(req0.url, status=status, headers=headers)
                 res1 = self._process_requestresponse(mw, req0, res0)
                 res304 = res0.replace(status=304)
@@ -354,7 +343,7 @@ class RFC2616PolicyTest(DefaultStorageTest):
         with self._middleware(HTTPCACHE_ALWAYS_STORE=True) as mw:
             for idx, (_, status, headers) in enumerate(responses):
                 shouldcache = 'no-store' not in headers.get('Cache-Control', '') and status != 304
-                req0 = Request('http://example2-%d.com' % idx)
+                req0 = Request(f'http://example2-{idx}.com')
                 res0 = Response(req0.url, status=status, headers=headers)
                 res1 = self._process_requestresponse(mw, req0, res0)
                 res304 = res0.replace(status=304)
@@ -397,7 +386,7 @@ class RFC2616PolicyTest(DefaultStorageTest):
         ]
         with self._middleware() as mw:
             for idx, (status, headers) in enumerate(sampledata):
-                req0 = Request('http://example-%d.com' % idx)
+                req0 = Request(f'http://example-{idx}.com')
                 res0 = Response(req0.url, status=status, headers=headers)
                 # cache fresh response
                 res1 = self._process_requestresponse(mw, req0, res0)
@@ -434,7 +423,7 @@ class RFC2616PolicyTest(DefaultStorageTest):
         ]
         with self._middleware() as mw:
             for idx, (status, headers) in enumerate(sampledata):
-                req0 = Request('http://example-%d.com' % idx)
+                req0 = Request(f'http://example-{idx}.com')
                 res0a = Response(req0.url, status=status, headers=headers)
                 # cache expired response
                 res1 = self._process_requestresponse(mw, req0, res0a)
@@ -501,7 +490,7 @@ class RFC2616PolicyTest(DefaultStorageTest):
         ]
         with self._middleware(HTTPCACHE_IGNORE_RESPONSE_CACHE_CONTROLS=['no-cache', 'no-store']) as mw:
             for idx, (status, headers) in enumerate(sampledata):
-                req0 = Request('http://example-%d.com' % idx)
+                req0 = Request(f'http://example-{idx}.com')
                 res0 = Response(req0.url, status=status, headers=headers)
                 # cache fresh response
                 res1 = self._process_requestresponse(mw, req0, res0)
@@ -512,5 +501,6 @@ class RFC2616PolicyTest(DefaultStorageTest):
                 self.assertEqualResponse(res1, res2)
                 assert 'cached' in res2.flags
 
+
 if __name__ == '__main__':
     unittest.main()
